@@ -1,17 +1,10 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::Chrome::ExtraPrompt;
-{
-  $Dist::Zilla::Plugin::Chrome::ExtraPrompt::VERSION = '0.006';
-}
-# git description: v0.005-1-g6e3387f
-
-BEGIN {
-  $Dist::Zilla::Plugin::Chrome::ExtraPrompt::AUTHORITY = 'cpan:ETHER';
-}
+package Dist::Zilla::Plugin::Chrome::ExtraPrompt; # git description: v0.006-20-g63414b8
 # ABSTRACT: Perform arbitrary commands when Dist::Zilla prompts you
-# vim: set ts=8 sw=4 tw=78 et :
-
+# KEYWORDS: prompt execute command external
+# vim: set ts=8 sts=4 sw=4 tw=78 et :
+our $VERSION = '0.007';
 use Moose;
 with 'Dist::Zilla::Role::Plugin';
 use namespace::autoclean;
@@ -29,6 +22,8 @@ has repeat_prompt => (
     default => 0,
 );
 
+# no dump_config, as what we do here should never be relevant to the outcome of the build
+
 around register_component => sub
 {
     my $orig = shift;
@@ -41,10 +36,7 @@ around register_component => sub
     $chrome->logger->log_fatal('must be used in ~/.dzil/config.ini -- NOT dist.ini!')
         if $section->sequence->assembler->can('zilla');
 
-    require Dist::Zilla::Chrome::Term;
-    Dist::Zilla::Chrome::Term->meta->make_mutable;
-    Moose::Util::apply_all_roles('Dist::Zilla::Chrome::Term', 'Dist::Zilla::Role::Chrome::ExtraPrompt');
-    Dist::Zilla::Chrome::Term->meta->make_immutable;
+    Moose::Util::apply_all_roles($chrome, 'Dist::Zilla::Role::Chrome::ExtraPrompt');
 
     if ($chrome->does('Dist::Zilla::Role::Chrome::ExtraPrompt'))
     {
@@ -58,18 +50,12 @@ around register_component => sub
 __PACKAGE__->meta->make_immutable;
 
 
-package Dist::Zilla::Role::Chrome::ExtraPrompt;
-{
-  $Dist::Zilla::Role::Chrome::ExtraPrompt::VERSION = '0.006';
-}
-# git description: v0.005-1-g6e3387f
-
-BEGIN {
-  $Dist::Zilla::Role::Chrome::ExtraPrompt::AUTHORITY = 'cpan:ETHER';
-}
+package Dist::Zilla::Role::Chrome::ExtraPrompt; # git description: v0.006-20-g63414b8
+our $VERSION = '0.007';
 use Moose::Role;
 use IPC::Open2;
 use File::Spec;
+use POSIX ':sys_wait_h';
 use namespace::autoclean;
 
 has command => (
@@ -99,8 +85,14 @@ around [qw(prompt_str prompt_yn)] => sub {
 
     my $pid = open2($out, $in, $command);
 
-    # when the user responds, kill the process (e.g. shuts up 'say')
+    # wait for the user to respond
     my $input = $self->$orig(@_);
+
+    # check what happened to the command
+    my $done = waitpid($pid, WNOHANG);
+    my $exit_status = $? >> 8;
+    warn "[Chrome::ExtraPrompt] process exited with status $exit_status\n" if $done and $exit_status;
+
     my $ret = kill 'KILL', $pid;
 
     return $input;
@@ -113,15 +105,13 @@ __END__
 
 =encoding UTF-8
 
-=for :stopwords Karen Etheridge irc
-
 =head1 NAME
 
 Dist::Zilla::Plugin::Chrome::ExtraPrompt - Perform arbitrary commands when Dist::Zilla prompts you
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 SYNOPSIS
 
@@ -143,19 +133,20 @@ OS X to provide an audio prompt to bring me back to this screen session.
 
 =head1 CONFIGURATION OPTIONS
 
-=over 4
+=head2 C<command>
 
-=item * C<command>: the string containing the command and arguments to call.
-required.
+The string containing the command and arguments to call.  required.
 
-=item * C<repeat_prompt>: a boolean flag (defaulting to false) that, when set,
+=head2 C<repeat_prompt>
+
+A boolean flag (defaulting to false) that, when set,
 appends the prompt string to the command and arguments that are called,
 passing as a single (additional?) argument.
 
-=back
-
 =head1 SUPPORT
 
+=for stopwords irc
+
 Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-Chrome-ExtraPrompt>
 (or L<bug-Dist-Zilla-Plugin-Chrome-ExtraPrompt@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-Chrome-ExtraPrompt@rt.cpan.org>).
 I am also usually active on irc, as 'ether' at C<irc.perl.org>.
